Index: test/must_pub_get_test.dart |
diff --git a/test/must_pub_get_test.dart b/test/must_pub_get_test.dart |
index 058ea89ae27e0681a29eb83ecb80902d80e91753..0381c5bbb3e1c9a6518115b9c249f953ea91e25a 100644 |
--- a/test/must_pub_get_test.dart |
+++ b/test/must_pub_get_test.dart |
@@ -293,16 +293,19 @@ foo:http://example.com/ |
]).create(); |
d.dir(appPath, [ |
- d.appPubspec({"foo": {"path": "../foo"}}) |
- ]); |
+ d.appPubspec({"bar": {"path": "../bar"}}) |
+ ]).create(); |
pubGet(); |
// Update foo's pubspec without touching the app's. |
d.dir("bar", [ |
d.libPubspec("bar", "1.0.0", deps: {"foo": "2.0.0"}) |
]).create(); |
}); |
+ |
+ _requiresPubGet('The pubspec.yaml file has changed since the ' |
+ 'pubspec.lock file was generated, please run "pub get" again.'); |
Bob Nystrom
2016/05/05 22:06:42
It would be really nice if the error message showe
@@ -293,16 +293,19 @@ foo:http://example.com/ |
pubGet(); |
- // Update foo's pubspec without touching the app's. |
+ // Update bar's pubspec without touching the app's. |
d.dir("bar", [ |
d.libPubspec("bar", "1.0.0", deps: {"foo": "2.0.0"}) |
nweiz
2016/05/05 22:29:49
Done.
|
}); |
}); |